api.documents.v1.customer package — Argus-Toolbelt 1.0 documentation

# api.documents.v1.customer package

## Submodules

## api.documents.v1.customer.customer module

Autogenerated API

`api.documents.v1.customer.customer.` `get_customer_root_folder`(customerID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch customer root folder (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (int) – ID of customer to fetch root folder for
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 932, “limit”: 815, “responseCode”: 200, “count”: 85, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Professor your than society along site.”, “messageTemplate”: “Man behind leg improve possible movie.”, “field”: “Responsibility animal wait.”, “parameter”: {}, “timestamp”: 23191458}], “currentPage”: 719, “size”: 830}

## Module contents